<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:portcom="http://www.indexdata.dk/TKL"
    xmlns:zebra="http://www.indexdata.dk/zebra/"
    version="1.0">

    <xsl:import href="tkl-file://interface.xsl"/>
    <xsl:include href="tkl-file://news.xsl"/>

    <xsl:output method="html" encoding="ISO-8859-1"/>

    <xsl:variable name="number" select="6"/>

    <xsl:param name="portpath"/>
    <xsl:param name="query"/>
    <xsl:param name="tkl_bin"/>
    <xsl:param name="tkl_authenticated"/>
    <xsl:param name="tkl_docroot"/>
    <xsl:param name="start" select="1"/>

<xsl:template match="/search">
    <xsl:call-template name="main-page"/>
</xsl:template>


<xsl:template name="main-news-content">
    <xsl:call-template name="read-news"/>
</xsl:template>

<!--

   Note: this template is a little less pretty than it could be because we can't get
   the current Zebra setup to sort records the way we want them (this may have changed
   by now. That means sorting of the entire result set takes place in the stylesheet.

-->

<xsl:template name="main-body">

    <span class="brown">
      <b xml:lang="en">Search</b>
      <b xml:lang="da">S&#xf8;gning</b>
    </span>

    <xsl:choose>
        <xsl:when test="$query">

	    <xsl:variable name="search" select="document(concat(
		'tkl-search://unix:', $portpath, '/db/socket?',
		'cclquery=', $query,
		'&amp;start=', '1',
		'&amp;syntax=xml',
		'&amp;number=', '99999',
		'&amp;alphasort=title'))"/>

	    <xsl:variable name="hits" select="$search/*/server/hits"/>

	    <xsl:variable name="records">
	      <xsl:for-each select="$search/*/server/record">
	        <xsl:sort select="*/title/@alphasort"/>
		<xsl:copy-of select="."/>
	      </xsl:for-each>
	    </xsl:variable>

	    <p/>

	    <xsl:choose>
		<xsl:when test="$search/error">
		    <p/>ERROR!!!!
		    '<xsl:value-of select="$search/error"/>'
		</xsl:when>

		<xsl:when test="$search/*/server/hits = 0">
		    <xsl:copy-of select="zerohits/node()"/>
		</xsl:when>

		<xsl:otherwise>
		    <b><xsl:value-of select="$hits"/>
		    <xsl:text> </xsl:text>
		    <span xml:lang="da">fund.</span>
		    <span xml:lang="en">hits.</span>
		    </b>

		    <p/>
		    <span xml:lang="en">Displaying records </span>
		    <span xml:lang="da">Viser posterne </span>
		    <xsl:value-of select="$start"/><xsl:text>-</xsl:text>
		    <xsl:choose>
		    <xsl:when test="$start + $number - 1 &lt; $hits">
		        <xsl:value-of select="$start + $number - 1"/>
		      </xsl:when>
		      <xsl:otherwise>
		        <xsl:value-of select="$hits"/>
		      </xsl:otherwise>
		    </xsl:choose>


		    <xsl:call-template name="previous-next">
		        <xsl:with-param name="search" select="$search"/>
		    </xsl:call-template>

		    <p/>

		    <xsl:for-each select="$records/record[position() &gt;= $start and position() &lt; $start + $number]">

		        <xsl:variable name="url">
			    <xsl:choose>
				<xsl:when test="*/identifier">
				    <xsl:value-of select="normalize-space(*/identifier)"/>
				</xsl:when>
				<xsl:otherwise>
				    <xsl:value-of select="
					concat($root, '/',
					normalize-space(*/zebra:idzebra/zebra:filename))"/>
				</xsl:otherwise>
			    </xsl:choose>
			</xsl:variable>

			<xsl:choose>
			    <xsl:when test="subject">
		                <img height="8" width="10"
					src="{$root}/gfx/square.gif"/>
			    </xsl:when>
			    <xsl:otherwise>
		                <img height="8" width="10"
					src="{$root}/gfx/arrow_brown_right.gif"/>
			    </xsl:otherwise>
			</xsl:choose>

			<a href="{$url}"><xsl:value-of select="*/title"/></a>

			<xsl:choose>
			    <xsl:when test="subject">
				<xml:text xml:lang="da"> (emnegruppe)</xml:text>
				<xml:text xml:lang="en"> (category)</xml:text>
			    </xsl:when>
			    <xsl:when test="link"/>
			    <xsl:otherwise>
				<xml:text xml:lang="da"> (lokal resource)</xml:text>
				<xml:text xml:lang="en"> (local resource)</xml:text>
			    </xsl:otherwise>
			</xsl:choose>

			<xsl:if test="$tkl_authenticated">
                            <a href="{$tkl_bin}/xform.php?xml_file={$tkl_docroot}{$root}/{*/zebra:idzebra/zebra:filename}"
                                onClick="window.open('', 'xform', 'width=600,height=600,screenX=1,screenY=1,top=1,left=1,resizable=y
es,scrollbars=1,scrolling=yes')" target="xform">
                                <img border="0" src="{$root}/gfx/edit.gif"/>
                            </a>
                        </xsl:if>


			<xsl:if test="normalize-space(*/description)">
			    <br/>
			    -<xsl:value-of select="*/description"/>
			</xsl:if>
			<xsl:if test="normalize-space(*/abstract)">
			    <br/>
			    -<em><xsl:value-of select="*/abstract"/></em>
			</xsl:if>
			<br/><br/>
		    </xsl:for-each>
		</xsl:otherwise>
	    </xsl:choose>
	</xsl:when>

	<!-- No Query -->
	<xsl:otherwise>
	    <p/>
	    <xsl:copy-of select="noterm/node()"/>
	</xsl:otherwise>
    </xsl:choose>
</xsl:template>


<xsl:template name="previous-next">
  <xsl:param name="search"/>

  <xsl:variable name="stuff">

    <!-- Make back button -->
    <xsl:if test="$start &gt; 1">

	<!-- Find previous starting point -->
        <xsl:variable name="prevstart">
	    <xsl:choose>
	        <xsl:when test="$start &lt; ($number + 1)">1</xsl:when>
		<xsl:otherwise>
		    <xsl:value-of select="$start - $number"/>
		</xsl:otherwise>
	    </xsl:choose>
	</xsl:variable>

        <a href="{concat(
	    $root, '/search.tkl', '?',
	    'utf8_query=', $query,
	    '&amp;start=', $prevstart)}">
	      <span xml:lang="en">Back</span>
	      <span xml:lang="da">Tilbage</span>
          </a> -
    </xsl:if>

    <!-- Make forward button -->
    <xsl:if test="$search/*/server/hits &gt;= $number + $search/*/start">
        <a href="{concat(
	    $root, '/search.tkl', '?',
	    'utf8_query=', $query,
	    '&amp;start=', $start + $number)}">
	    <span xml:lang="en">More</span>
	    <span xml:lang="da">Flere</span>
        </a>
    </xsl:if>
  </xsl:variable>

  <xsl:if test="$stuff">
      --- <xsl:copy-of select="$stuff"/>
  </xsl:if>
</xsl:template>

</xsl:stylesheet>
